@@ -173,6 +173,8 @@ def django_instance_field_to_redis_value(
         redis_root,
         create_redis_model_from_django_model
 ):
+    print(django_instance.__class__)
+    print(django_instance.__class__._meta.get_all_field_names())
     django_field_value = getattr(django_instance, django_field.name)
     redis_value = django_field_value
     if django_field.__class__ == django_fields.ForeignKey:
