@@ -444,8 +444,11 @@ class RedisRoot:
                             value = getattr(django_field, django_field_param_name)
                             if django_field_param_name == 'choices':
                                 real_value = {}
-                                for choice in value:
-                                    real_value[choice[0]] = choice[1]
+                                if value is not None:
+                                    for choice in value:
+                                        real_value[choice[0]] = choice[1]
+                                else:
+                                    real_value = None
                                 value = real_value
                             allowed_redis_params[django_field_param_name] = value
                     return allowed_redis_params
